#-----------------------------------------------------------------------------
#
#   Supersymmetry - Particles
#
#-----------------------------------------------------------------------------

from albow.controls import Label, Button
from albow.layout import Column
from albow.dialogs import Dialog, alert
from albow.resource import get_font, get_sound
from detection import DetectorView

wrong_sound = get_sound("wrong.ogg")

#-----------------------------------------------------------------------------

class DiscoveryDialog(Dialog):

	font1 = get_font(20, "VeraBd.ttf")
	font2 = get_font(14, "Vera.ttf")
	font3 = get_font(16, "VeraBd.ttf")

	def __init__(self, particle, game):
		text = Column([
			Label("Congratulations!", font = self.font1),
			Label("You've found the", font = self.font2),
			Label(particle.name.upper(), font = self.font3),
		], align = 'c')
		img = game.detector_image
		w, h = img.get_size()
		detector = DetectorView(game, size = (w + 8, h + 8), always_visible = True)
		contents = Column([
			text,
			detector,
			#Button("Hooray", action = self.ok),
		], align = 'c', spacing = 20)
		Dialog.__init__(self, client = contents, responses = ["Hooray!"], margin = 20)

#-----------------------------------------------------------------------------

class Particle(object):

	discovery_chance = 0.01 # per tick

	def __init__(self, name, is_real = True, comment = None):
		self.name = name
		self.is_real = is_real
		self.comment = comment
	
	def announce_discovery(self, game):
		dlog = DiscoveryDialog(self, game)
		dlog.present()
		if self.comment:
			if not self.is_real:
				wrong_sound.play()
			alert(self.comment)

#-----------------------------------------------------------------------------

def get(i):
	return particle_list[i]

def num_particles():
	#return 1 ###
	return len(particle_list)

particle_list = [
	Particle("selectron"),
	Particle("photino"),
	Particle("sneutrino"),
	Particle("arduino", False, "Oops, no, the Arduino is a computer, not a particle. Sorry. Carry on."),
	Particle("smuon"),
	Particle("gluino"),
	Particle("stauon"),
	Particle("bambino", False, "Wait a minute, that's a Japanese cooking manga. Someone is playing silly buggers with the particle list."),
	Particle("down squark"),
	Particle("up squark"),
	Particle("wino", True, "That's not a joke, by the way. The wino is really a particle."),
	Particle("strange squark"),
	Particle("gravitino", True, "Warning: Excessive gravitino concentration from here on could form a quantum black hole and swallow the earth. Proceed with caution."),
	Particle("charm squark"),
	Particle("bottom squark"),
	Particle("zino"),
	Particle("top squark"),
]
